.. Weblate manual documentation master file, created by
   sphinx-quickstart on Wed Mar  7 14:48:43 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Weblate's documentation!
===================================

Contents:

.. toctree::
    :maxdepth: 2

    about
    user/index
    devel/index
    admin/index
    faq
    formats
    vcs
    api
    wlc
    python
    changes
    contributing
    license


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
